@@ -1,16 +1,15 @@
 # encoding: utf-8
 
-"""
-Mappings from the ISO/IEC 29500 spec or inferred from PowerPoint application
-behavior
-"""
+"""Mappings from the ISO/IEC 29500 spec.
 
-from __future__ import absolute_import
+Some of these are inferred from PowerPoint application behavior
+"""
 
 from pptx.enum.shapes import MSO_SHAPE
 
 
 GRAPHIC_DATA_URI_CHART = "http://schemas.openxmlformats.org/drawingml/2006/chart"
+GRAPHIC_DATA_URI_OLEOBJ = "http://schemas.openxmlformats.org/presentationml/2006/ole"
 GRAPHIC_DATA_URI_TABLE = "http://schemas.openxmlformats.org/drawingml/2006/table"
 
 
